@@ -338,7 +338,7 @@ DrumEdit::DrumEdit(MusECore::PartList* pl, QWidget* parent, const char* name, un
 
       QToolBar* cursorToolbar = addToolBar(tr("cursor tools"));
       cursorToolbar->setObjectName("cursor");
-      QLabel *stepStr = new QLabel("Cursor step:");
+      QLabel *stepStr = new QLabel(tr("Cursor step:"));
       cursorToolbar->addWidget(stepStr);
       stepLenWidget = new QComboBox();
       stepLenWidget->setToolTip(tr("Set step size for cursor edit"));
@@ -401,7 +401,7 @@ DrumEdit::DrumEdit(MusECore::PartList* pl, QWidget* parent, const char* name, un
       gridS2->setSpacing(0);  
       time                = new MusEGui::MTScale(&_raster, split1w2, xscale);
       canvas              = new DrumCanvas(this, split1w2, xscale, yscale);
-      vscroll             = new MusEGui::ScrollScale(-4, 1, yscale, DRUM_MAPSIZE*TH, Qt::Vertical, split1w2);
+      vscroll             = new MusEGui::ScrollScale(-2, 1, yscale, DRUM_MAPSIZE*TH, Qt::Vertical, split1w2);
       int offset = -(MusEGlobal::config.division/4);
       canvas->setOrigin(offset, 0);
       canvas->setCanvasTools(drumeditTools);
@@ -1296,7 +1296,7 @@ void DrumEdit::keyPressEvent(QKeyEvent* event)
       else if (key == shortcuts[SHRT_ZOOM_IN].key) {
             int mag = hscroll->mag();
             int zoomlvl = MusEGui::ScrollScale::getQuickZoomLevel(mag);
-            if (zoomlvl < 23)
+            if (zoomlvl < MusEGui::ScrollScale::zoomLevels-1)
                   zoomlvl++;
 
             int newmag = MusEGui::ScrollScale::convertQuickZoomLevelToMag(zoomlvl);
