@@ -1098,7 +1098,7 @@ void PianoRoll::keyPressEvent(QKeyEvent* event)
       else if (key == shortcuts[SHRT_ZOOM_IN].key) {
             int mag = hscroll->mag();
             int zoomlvl = MusEGui::ScrollScale::getQuickZoomLevel(mag);
-            if (zoomlvl < 23)
+            if (zoomlvl < MusEGui::ScrollScale::zoomLevels-1)
                   zoomlvl++;
 
             int newmag = MusEGui::ScrollScale::convertQuickZoomLevelToMag(zoomlvl);
